#
# spec file for package trytond_country
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%define pythons python3
%define mypython python3
%define mysitelib %python3_sitelib
%else
%{?sle15_python_module_pythons}
%define mypython %pythons
%define mysitelib %{expand:%%%{mypython}_sitelib}
%endif

%define majorver 6.0
Name:           trytond_country
Version:        %{majorver}.3
Release:        5.2
Summary:        The "country" module for the Tryton ERP system
License:        GPL-3.0-only
Group:          Productivity/Office/Management
URL:            http://www.tryton.org/
Source:         http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz
## Source2:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz.asc
## Source3:        https://keybase.io/cedrickrier/pgp_keys.asc?fingerprint=7C5A4360F6DF81ABA91FD54D6FF50AFE03489130#/%{name}.keyring
Patch0:         001_pycountry.diff
Patch1:         002_support_pycountry_22.diff
Patch2:         003_revert_pycountry_limit.diff
# List of additional build dependencies
BuildRequires:  %{mypython}-devel
BuildRequires:  %{mypython}-pip
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-wheel
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
BuildRequires:  python-rpm-macros
Requires:       %{mypython}-pycountry
Requires:       proteus
Requires:       trytond
BuildArch:      noarch

%description
The country module defines the concepts of country and subdivision in
the Tryton application platform. The module comes preloaded with the
ISO 3166 list of countries and subdivisions thanks to the pycountry
module.

%prep
%setup -q
# TW uses newer pycountry
%if 0%{?suse_version} > 1500
%patch -P 0 -P 1 -P 2 -p1
%endif

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{mysitelib}

%files
%defattr(-,root,root)
%attr(755,root,tryton) %{_bindir}/trytond_import*
%{mysitelib}/tryton*

%changelog
* Mon Apr 29 2024 Axel Braun <axel.braun@gmx.de>
- sources not signed anymore
* Mon Feb 26 2024 Ben Greiner <code@bnavigator.de>
- Clean up some obsolete specfile directives
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Jan 13 2024 Axel Braun <axel.braun@gmx.de>
- Switch to wheel and %%{?sle15_python_module_pythons}
  limit on pycountry version spec file removed
* Thu Oct 19 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Remove %%python3_install prefix and root options, that's included in
  the macro by default.
* Tue Oct 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.3 - Bugfix Release
  001_pycountry.diff adapted
* Fri Mar 18 2022 Axel Braun <axel.braun@gmx.de>
- patches reorganized:
  pycountry.diff removed
  added:
  001_pycountry.diff
  002_support_pycountry_22.diff
  003_revert_pycountry_limit.diff
* Mon Mar 14 2022 Axel Braun <axel.braun@gmx.de>
- revert_pycountry_limit.diff added
  fixes boo#1196857
* Tue Mar  8 2022 Axel Braun <axel.braun@gmx.de>
- added pycountry.diff (https://bugs.tryton.org/issue11128 )
  build-conditions for TW added
* Tue Mar  8 2022 Axel Braun <axel.braun@gmx.de>
- runtime dependency python-pycountry added
* Sat Feb 12 2022 Axel Braun <axel.braun@gmx.de>
- Version bump to Tryton 6.0 series
* Fri Jun 18 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.3 - Bugfix Release
* Sat Feb 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Sun Jan 24 2021 Axel Braun <axel.braun@gmx.de>
- Adaption to new python macros
* Sat Apr  4 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.2 - Bugfix Release
* Thu Nov 21 2019 Axel Braun <axel.braun@gmx.de>
- version 5.0.1 (GNU Health 3.6 series)
* Wed Nov 29 2017 axel.braun@gmx.de
- Version 4.6.0
* Mon Nov 28 2016 axel.braun@gmx.de 
- Tryton Release 4.2
* Mon May  2 2016 axel.braun@gmx.de 
- Tryton Release 4.0
* Mon Oct 19 2015 axel.braun@gmx.de 
- Tryton Release 3.8
* Wed Apr 15 2015 axel.braun@gmx.de 
- Tryton Release 3.6
* Fri Oct 25 2013 axel.braun@gmx.de
- new branch 3.0
* Thu May  2 2013 axel.braun@gmx.de
- initial build
